import { SubmissionStatus } from "@/state/reducer/submission";
import React from "react";
import { ClockOutline, FileQuestion, NotebookCheckOutline, NotebookEditOutline, NotebookRemoveOutline } from "mdi-material-ui";
import { useTranslation } from "react-i18next";
import { Chip } from "@material-ui/core";
import { createStyles, makeStyles, Theme } from "@material-ui/core/styles";
import { green, orange, red } from "@material-ui/core/colors";
import { InternshipSubmission } from "@/management/api/internship";

const useStateLabelStyles = makeStyles((theme: Theme) => createStyles<SubmissionStatus, {}>({
    awaiting: {
        borderColor: orange["800"],
        color: orange["800"],
    },
    declined: {
        borderColor: red["600"],
        color: red["600"],
    },
    draft: {},
    accepted: {
        borderColor: green["600"],
        color: green["600"]
    }
}))

export type StateLabelProps = {
    state: SubmissionStatus | null;
};

export const isValidState = (state: string | null) => ["accepted", "draft", "awaiting", "declined"].includes(state as string)

export const StateLabel = ({ state }: StateLabelProps) => {
    const icons: { [sate in SubmissionStatus]: React.ReactElement } = {
        accepted: <NotebookCheckOutline/>,
        awaiting: <ClockOutline/>,
        declined: <NotebookRemoveOutline/>,
        draft: <NotebookEditOutline/>
    }

    const classes = useStateLabelStyles();

    const { t } = useTranslation();

    return isValidState(state)
        ? <Chip icon={ icons[state as SubmissionStatus] } label={ t(`translation:submission.status.${ state }`) } variant="outlined" className={ classes[state as SubmissionStatus] }/>
        : <Chip icon={ <FileQuestion /> } label={ t(`translation:submission.status.empty`) } variant="outlined"/>
}

export const canEdit = (internship: InternshipSubmission) => internship.state != "draft";
export const canAccept = (internship: InternshipSubmission) => ["declined", "awaiting"].includes(internship.state);
export const canDiscard = (internship: InternshipSubmission) => ["accepted", "awaiting"].includes(internship.state);
